@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 # Preloaded methods go here.
 
@@ -321,7 +321,7 @@ sub _init {
 
 =head1 NAME
 
-SSN::Validate - Perl extension do SSN Validation
+SSN::Validate - Perl extension to do SSN Validation
 
 =head1 SYNOPSIS
 
@@ -428,9 +428,11 @@ it.. or will return an empty string.
 
 * Consider SSN::Validate::SSDI for Social Security Death Index (SSDI)
 
-* Add 'invalid' param to new() to allow showing assigned, but not
-issued, AREAs as valid. The SSA considers them invalid, but someone may
-want to have the included.
+* Possibly change how data is stored (first on TODO), and provide my
+	extract script for people to run on their own. This way, maybe they
+	could update the SSA changes on their own, instead of being dependant
+	on the module for this, or having to update the module when the SSA
+	makes changes. I think I like this idea.
 
 =head2 EXPORT
 
@@ -584,7 +586,7 @@ __DATA__
 019,88
 020,88
 021,88
-022,86
+022,88
 023,86
 024,86
 025,86
@@ -652,9 +654,9 @@ __DATA__
 087,94
 088,94
 089,94
-090,92
-091,92
-092,92
+090,94
+091,94
+092,94
 093,92
 094,92
 095,92
@@ -706,7 +708,7 @@ __DATA__
 141,15
 142,15
 143,15
-144,13
+144,15
 145,13
 146,13
 147,13
@@ -746,7 +748,7 @@ __DATA__
 181,82
 182,82
 183,82
-184,80
+184,82
 185,80
 186,80
 187,80
@@ -779,7 +781,7 @@ __DATA__
 214,71
 215,71
 216,71
-217,69
+217,71
 218,69
 219,69
 220,69
@@ -836,7 +838,7 @@ __DATA__
 271,11
 272,11
 273,11
-274,08
+274,11
 275,08
 276,08
 277,08
@@ -869,7 +871,7 @@ __DATA__
 304,29
 305,29
 306,29
-307,27
+307,29
 308,27
 309,27
 310,27
@@ -895,8 +897,8 @@ __DATA__
 330,04
 331,04
 332,04
-333,02
-334,02
+333,04
+334,04
 335,02
 336,02
 337,02
@@ -936,7 +938,7 @@ __DATA__
 371,31
 372,31
 373,31
-374,29
+374,31
 375,29
 376,29
 377,29
@@ -959,7 +961,7 @@ __DATA__
 394,25
 395,25
 396,25
-397,23
+397,25
 398,23
 399,23
 400,63
@@ -973,7 +975,7 @@ __DATA__
 408,99
 409,99
 410,99
-411,97
+411,99
 412,97
 413,97
 414,97
@@ -1038,7 +1040,7 @@ __DATA__
 473,45
 474,45
 475,45
-476,43
+476,45
 477,43
 478,35
 479,35
@@ -1100,7 +1102,7 @@ __DATA__
 535,55
 536,55
 537,55
-538,53
+538,55
 539,53
 540,67
 541,67
@@ -1140,7 +1142,7 @@ __DATA__
 575,99
 576,99
 577,39
-578,37
+578,39
 579,37
 580,35
 581,99
@@ -1170,13 +1172,13 @@ __DATA__
 606,49
 607,49
 608,49
-609,47
-610,47
-611,47
-612,47
-613,47
-614,47
-615,47
+609,49
+610,49
+611,49
+612,49
+613,49
+614,49
+615,49
 616,47
 617,47
 618,47
@@ -1200,9 +1202,9 @@ __DATA__
 636,94
 637,94
 638,94
-639,92
-640,92
-641,92
+639,94
+640,94
+641,94
 642,92
 643,92
 644,92
@@ -1213,7 +1215,7 @@ __DATA__
 649,34
 650,34
 651,34
-652,32
+652,34
 653,32
 654,20
 655,18
@@ -1223,7 +1225,7 @@ __DATA__
 659,10
 660,10
 661,10
-662,09
+662,10
 663,09
 664,09
 665,09
@@ -1234,16 +1236,16 @@ __DATA__
 671,24
 672,24
 673,24
-674,22
-675,22
+674,24
+675,24
 676,09
 677,09
 678,07
 679,07
-680,62
+680,64
 681,07
-682,05
-683,05
+682,07
+683,07
 684,05
 685,05
 686,05
@@ -1253,6 +1255,7 @@ __DATA__
 690,05
 691,01
 692,01
+693,01
 700,18
 701,18
 702,18
@@ -1293,10 +1296,10 @@ __DATA__
 765,48
 766,36
 767,36
-768,34
-769,34
-770,34
-771,34
+768,36
+769,36
+770,36
+771,36
 772,34
 900,70-80 ## Individual Taxpayer Identification Number
 900,93-93 ## Adoption Taxpayer Identification Number
